==> node-postgres_8.12.0+~cs35.15.26.orig.tar.gz: node-postgres-pg-8.12.0/packages/pg/test/unit/client/escape-tests.js <==
'use strict'
var helper = require('./test-helper')
var utils = require('../../../lib/utils')

function createClient(callback) {
  var client = new Client(helper.config)
  client.connect(function (err) {
    return callback(client)
  })
}

var testLit = function (testName, input, expected) {
  test(testName, function () {
    var client = new Client(helper.config)
    var actual = client.escapeLiteral(input)
    assert.equal(expected, actual)
  })

  test('Client.prototype.' + testName, function () {
    var actual = Client.prototype.escapeLiteral(input)
    assert.equal(expected, actual)
  })

  test('utils.' + testName, function () {
    var actual = utils.escapeLiteral(input)
    assert.equal(expected, actual)
  })
}

var testIdent = function (testName, input, expected) {
  test(testName, function () {
    var client = new Client(helper.config)
    var actual = client.escapeIdentifier(input)
    assert.equal(expected, actual)
  })

  test('Client.prototype.' + testName, function () {
    var actual = Client.prototype.escapeIdentifier(input)
    assert.equal(expected, actual)
  })

  test('utils.' + testName, function () {
    var actual = utils.escapeIdentifier(input)
    assert.equal(expected, actual)
  })
}

testLit('escapeLiteral: no special characters', 'hello world', "'hello world'")

testLit('escapeLiteral: contains double quotes only', 'hello " world', "'hello \" world'")

testLit('escapeLiteral: contains single quotes only', "hello ' world", "'hello '' world'")

testLit('escapeLiteral: contains backslashes only', 'hello \\ world', " E'hello \\\\ world'")

testLit('escapeLiteral: contains single quotes and double quotes', 'hello \' " world', "'hello '' \" world'")

testLit('escapeLiteral: contains double quotes and backslashes', 'hello \\ " world', " E'hello \\\\ \" world'")

testLit('escapeLiteral: contains single quotes and backslashes', "hello \\ ' world", " E'hello \\\\ '' world'")

testLit(
  'escapeLiteral: contains single quotes, double quotes, and backslashes',
  'hello \\ \' " world',
  " E'hello \\\\ '' \" world'"
)

testIdent('escapeIdentifier: no special characters', 'hello world', '"hello world"')

testIdent('escapeIdentifier: contains double quotes only', 'hello " world', '"hello "" world"')

testIdent('escapeIdentifier: contains single quotes only', "hello ' world", '"hello \' world"')

testIdent('escapeIdentifier: contains backslashes only', 'hello \\ world', '"hello \\ world"')

testIdent('escapeIdentifier: contains single quotes and double quotes', 'hello \' " world', '"hello \' "" world"')

testIdent('escapeIdentifier: contains double quotes and backslashes', 'hello \\ " world', '"hello \\ "" world"')

testIdent('escapeIdentifier: contains single quotes and backslashes', "hello \\ ' world", '"hello \\ \' world"')

testIdent(
  'escapeIdentifier: contains single quotes, double quotes, and backslashes',
  'hello \\ \' " world',
  '"hello \\ \' "" world"'
)

==> node-postgres_8.13.1+~cs35.16.31.orig.tar.gz: node-postgres-pg-8.13.1/packages/pg/test/unit/client/escape-tests.js <==
'use strict'
var helper = require('./test-helper')
var utils = require('../../../lib/utils')
const assert = require('assert')
const { Client, Suite } = helper
const suite = new Suite()
const test = suite.test.bind(suite)

var testLit = function (testName, input, expected) {
  test(testName, function () {
    var client = new Client(helper.config)
    var actual = client.escapeLiteral(input)
    assert.equal(expected, actual)
  })

  test('Client.prototype.' + testName, function () {
    var actual = Client.prototype.escapeLiteral(input)
    assert.equal(expected, actual)
  })

  test('utils.' + testName, function () {
    var actual = utils.escapeLiteral(input)
    assert.equal(expected, actual)
  })
}

var testIdent = function (testName, input, expected) {
  test(testName, function () {
    var client = new Client(helper.config)
    var actual = client.escapeIdentifier(input)
    assert.equal(expected, actual)
  })

  test('Client.prototype.' + testName, function () {
    var actual = Client.prototype.escapeIdentifier(input)
    assert.equal(expected, actual)
  })

  test('utils.' + testName, function () {
    var actual = utils.escapeIdentifier(input)
    assert.equal(expected, actual)
  })
}

testLit('escapeLiteral: no special characters', 'hello world', "'hello world'")

testLit('escapeLiteral: contains double quotes only', 'hello " world', "'hello \" world'")

testLit('escapeLiteral: contains single quotes only', "hello ' world", "'hello '' world'")

testLit('escapeLiteral: contains backslashes only', 'hello \\ world', " E'hello \\\\ world'")

testLit('escapeLiteral: contains single quotes and double quotes', 'hello \' " world', "'hello '' \" world'")

testLit('escapeLiteral: contains double quotes and backslashes', 'hello \\ " world', " E'hello \\\\ \" world'")

testLit('escapeLiteral: contains single quotes and backslashes', "hello \\ ' world", " E'hello \\\\ '' world'")

testLit(
  'escapeLiteral: contains single quotes, double quotes, and backslashes',
  'hello \\ \' " world',
  " E'hello \\\\ '' \" world'"
)

testIdent('escapeIdentifier: no special characters', 'hello world', '"hello world"')

testIdent('escapeIdentifier: contains double quotes only', 'hello " world', '"hello "" world"')

testIdent('escapeIdentifier: contains single quotes only', "hello ' world", '"hello \' world"')

testIdent('escapeIdentifier: contains backslashes only', 'hello \\ world', '"hello \\ world"')

testIdent('escapeIdentifier: contains single quotes and double quotes', 'hello \' " world', '"hello \' "" world"')

testIdent('escapeIdentifier: contains double quotes and backslashes', 'hello \\ " world', '"hello \\ "" world"')

testIdent('escapeIdentifier: contains single quotes and backslashes', "hello \\ ' world", '"hello \\ \' world"')

testIdent(
  'escapeIdentifier: contains single quotes, double quotes, and backslashes',
  'hello \\ \' " world',
  '"hello \\ \' "" world"'
)
